CuReBottomNavigationBarItem class

Constructors

CuReBottomNavigationBarItem({IconData? icon, IconData? activeIcon, String? label, Widget? widgetIcon, Widget? activeWidgetIcon, String? tooltip, Color? color})

Properties

activeIcon IconData?
final
activeWidgetIcon Widget?
final
color Color?
final
hashCode int
The hash code for this object.
no setterinherited
icon IconData?
final
label String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tooltip String?
final
widgetIcon Widget?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited