CuReSettingsItem class
Constructors
- CuReSettingsItem({IconData? icon, Widget? iconChild, String? description, required Widget child, Color? color, VoidCallback? onTap})
Properties
- child → Widget
-
final
- color → Color?
-
final
- description → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → IconData?
-
final
- iconChild → Widget?
-
final
- onTap → VoidCallback?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited