CuReLocalization class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
get(
String key) → String -
getSystemLanguage(
{String fallbackLanguage = 'en'}) → String -
setLanguage(
String locale) → void -
setValues(
Map< String, Map< values) → voidString, dynamic> > -
useSystemLanguage(
{String fallbackLanguage = 'en'}) → void